![enigma-cipher](https://github.com/1darshanpatil/enigmacipher/assets/72539638/7ed29d47-177b-4c86-bc12-c3517dd9a67c)


# EnigmaCipher

A Python package that simulates the encryption and decryption mechanisms of an Enigma machine with PIN protection.

## Capabilities
 * Utilize the shuffle command to introduce new rotors
 * Securely encrypt and decrypt messages with a PIN-based system

## Installation

To install EnigmaCipher, simply run:

```bash
pip install enigmacifra
```

Verify the installation by checking the version: 
```bash
$ enigma --version
```

## Usage

The EnigmaCipher package can be used via the command line.

### Command Line

To shuffle rotors:

```bash
$ enigma shuffle
```

To encrypt a message:

```bash
$ enigma encrypt
```

To decrypt a message:
 
```bash
$ enigma decrypt
```



## Development

To contribute to EnigmaCipher, clone the repository and make sure to install the development dependencies.

```bash
git clone https://github.com/1darshanpatil/enigmacipher
cd enigmacipher
pip install -e .
```

## Support

If you encounter any problems or have suggestions, please file an issue on the [GitHub issue tracker](https://github.com/1darshanpatil/enigmacipher/issues).

## License

The project is licensed under the MIT license.
